# Updating Lifecycle Phases
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phases#overview)
  * [Configuration](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phases#configuration)
  * [Script](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phases#script)


Configure an automation with a script to update lifecycle phases on applications based on your defined timeframes.
